@@ -239,12 +239,19 @@ class quiet(object):
 
     """
     def __enter__(self):
+        try:
+            self.null_fd = os.open(os.devnull, os.O_RDWR)
+        except OSError:
+            # If dev/null isn't writeable, then they just have to put up with
+            # the noise.
+            return
         self.stderr_fd = sys.__stderr__.fileno()
-        self.null_fd = os.open(os.devnull, os.O_RDWR)
         self.old = os.dup(self.stderr_fd)
         os.dup2(self.null_fd, self.stderr_fd)
 
     def __exit__(self, *args, **kwargs):
+        if not getattr(self, 'null_fd', None):
+            return
         os.dup2(self.old, self.stderr_fd)
         os.close(self.null_fd)
         os.close(self.old)
